Learn R Programming

finbif (version 0.9.12)

finbif_request_token: Get a FinBIF personal access token

Description

Have a personal access token for use with the FinBIF API sent to a specified email address.

Usage

finbif_request_token(email, quiet = FALSE)

finbif_renew_token(email, quiet = FALSE)

Value

If an access token has already been set then NULL (invisibly) if not then, invisibly, a finbif_api object containing the response from the FinBIF server.

Arguments

email

Character. The email address to which to send the API access token.

quiet

Logical. Suppress messages.

Examples

Run this code
if (FALSE) {

# Request a token for example@email.com
finbif_request_token("example@email.com")

Sys.unsetenv("FINBIF_ACCESS_TOKEN")

finbif_renew_token("example@email.com")

}

Run the code above in your browser using DataLab