Learn R Programming

finbif (version 0.9.12)

finbif_last_mod: Get last modified date for FinBIF occurrence records

Description

Get last modified date for filtered occurrence data from FinBIF.

Usage

finbif_last_mod(..., filter)

Value

A Date object

Arguments

...

Character vectors or list of character vectors. Taxa of records to download.

filter

List of named character vectors. Filters to apply to records.

Examples

Run this code
if (FALSE) {

# Get last modified date for Whooper Swan occurrence records from Finland
finbif_last_mod("Cygnus cygnus", filter = c(country = "Finland"))

}

Run the code above in your browser using DataLab