powered by
Get last modified date for filtered occurrence data from FinBIF.
finbif_last_mod(..., filter)
A Date object
Date
Character vectors or list of character vectors. Taxa of records to download.
List of named character vectors. Filters to apply to records.
if (FALSE) { # Get last modified date for Whooper Swan occurrence records from Finland finbif_last_mod("Cygnus cygnus", filter = c(country = "Finland")) }
Run the code above in your browser using DataLab